courses.Slot (Timetable Slot) — amici1

# `courses.Slot` (Timetable Slot)

Slot(id, seqno, start_time, end_time, name)

Master tables : courses.Slots (Timetable Slots)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- No. (seqno) : The sequence number of this item with its parent.

- Start Time (start_time) : See `<lino.core.fields.TimeField: start_time>`.

- End Time (end_time) : See `<lino.core.fields.TimeField: end_time>`.

- Name (name) : See `<django.db.models.fields.CharField: name>`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

- Name (name_column) : See `lino_xl.lib.courses.models.Slot.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.courses.models.Slot.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.courses.models.Slot.overview`.

Referenced from courses.Course.slot

## Database fields

Internal name | Verbose name | Help text
id | ID |
seqno | No. | The sequence number of this item with its parent.
start_time | Start Time |
end_time | End Time |
name | Name |
move_buttons | Move | Displays buttons for certain actions on this row:
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |